<?xml version="1.0" ?><!DOCTYPE TS><TS language="vi_VN" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Look</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>SingleWindow</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Roster position</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Choose position of roster in Single Window mode</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Left</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Right</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to previous tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch to next tab</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show/hide roster</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Switch focus between roster and tabs</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Behavior</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>